function Draw(Data,varargin)
%Draw - Display the specified data
%
%   Draw(P) displays all the points in matrix P, where each row of P stands
%   for one point, and each column of P stands for one dimension.
%
%   Draw(P,Name,Value,...) displays the points with the specified style.
%
%   Example:
%       Draw(rand(100,3))
%
%   If each point contains 2 or 3 dimensions, the points will be displayed
%   on 2-D or 3-D space. If the number of dimensions of each point is more
%   than 3, display the points on a 2-D figure, where each value of
%   abscissa stands for one dimension, and each value of ordinate stands
%   for the value of the corresponding dimension.

% Copyright 2015-2016 Ye Tian

    [N,M] = size(Data);

    if nargin < 2
        if M == 2
            varargin = {'ok','MarkerSize',6,'Marker','o','Markerfacecolor',[.7 .7 .7],'Markeredgecolor',[.4 .4 .4]};
        elseif M == 3
            varargin = {'ok','MarkerSize',8,'Marker','o','Markerfacecolor',[.7 .7 .7],'Markeredgecolor',[.4 .4 .4]};
        else
            varargin = {'-k','Color',[.5 .5 .5],'LineWidth',2};
        end
    end
	hold on; box on;
    set(gca,'Fontname','Times New Roman','Fontsize',13);
    if M == 2
        plot(Data(:,1),Data(:,2),varargin{:});
        xlabel('\itf\rm_1'); ylabel('\itf\rm_2');
        set(gca,'XTickMode','auto','YTickMode','auto','View',[0 90]);
    elseif M == 3
        plot3(Data(:,1),Data(:,2),Data(:,3),varargin{:});
        xlabel('\itf\rm_1'); ylabel('\itf\rm_2'); zlabel('\itf\rm_3');
        set(gca,'XTickMode','auto','YTickMode','auto','ZTickMode','auto','View',[135 30]);
    else
        for n = 1 : N
            plot(Data(n,:),varargin{:});
        end
        xlabel('Objective No.'); ylabel('Objective Value');
        set(gca,'XTick',1:ceil(M/10):M,'YTickMode','auto','View',[0 90]);
    end
    axis tight;
end