function Next = EnvironmentalSelection(ObjValue,N)
% The environmental selection of LMEA

% Copyright 2015-2016 Ye Tian

    %% Non-dominated sorting
    [FrontNO,MaxFNO] = ENS(ObjValue,N);
    Next = false(1,length(FrontNO));
    Next(FrontNO<MaxFNO) = true;

    %% Select the solutions in the last front
    Last   = find(FrontNO==MaxFNO);
    Choose = Truncation(ObjValue(Last,:),N-sum(Next));
    Next(Last(Choose)) = true;
end

function Choose = Truncation(ObjValue,K)
% Select part of the solutions by truncation

    %% Calculate the normalized angle between each two solutions
    fmax     = max(ObjValue,[],1);
    fmin     = min(ObjValue,[],1);
    ObjValue = (ObjValue-repmat(fmin,size(ObjValue,1),1))./repmat(fmax-fmin,size(ObjValue,1),1);
    Cosine   = 1 - pdist2(ObjValue,ObjValue,'cosine');
    Cosine(logical(eye(length(Cosine)))) = 0;
    
    %% Truncation
    % Choose the extreme solutions first
    Choose = false(1,size(ObjValue,1)); 
    [~,extreme] = max(ObjValue,[],1);
    Choose(extreme) = true;
    % Choose the rest by truncation
    if sum(Choose) > K
        selected = find(Choose);
        Choose   = selected(randperm(length(selected),K));
    else
        while sum(Choose) < K
            unSelected = find(~Choose);
            [~,x]      = min(max(Cosine(~Choose,Choose),[],2));
            Choose(unSelected(x)) = true;
        end
    end
end