function index = TournamentSelection(K,N,varargin)
%TournamentSelection - Tournament selection
%
%   P = TournamentSelection(K,N,fitness1,fitness2,...) returns the indexes
%   of N solutions by K-tournament selection based on their fitness values.
%   In each selection, the candidate having the minimum fitness1 value will
%   be selected; if more than one candidates have the same minimum fitness1
%   value, then consider their fitness2 values, and so on.
%
%   Example:
%       P = TournamentSelection(2,100,FrontNO)

% Copyright 2015-2016 Ye Tian

    varargin = cellfun(@(S)reshape(S,length(varargin{1}),1),varargin,'UniformOutput',false);
    [~,rank] = sortrows([varargin{:}]);
    [~,rank] = sort(rank);
    Parents  = randi(length(varargin{1}),K,N);
    [~,best] = min(rank(Parents),[],1);
    index    = Parents(best+(0:N-1)*K);
end