function Offspring = VariationSpecial(Population,Parents,DecVariables,operator,Boundary)
% The variation function for special algorithms (LMEA), where the operator
% only works on several decision variables. This function now only supports
% the operators of SBX with PolynomialM and DE with PolynomialM

% Copyright 2015-2016 Ye Tian

    %% Generate offsprings on several decision variables
    ParentDec = Parents(:,DecVariables);
    [N,D]     = size(ParentDec);
    if strcmp(operator,'SBX')
        % SBX
        [proC,disC] = deal(1,20);
        parent1Dec  = ParentDec(1:N/2,:);
        parent2Dec  = ParentDec(N/2+1:end,:);
        beta = zeros(N/2,D);
        miu  = rand(N/2,D);
        beta(miu<=0.5) = (2*miu(miu<=0.5)).^(1/(disC+1));
        beta(miu>0.5)  = (2-2*miu(miu>0.5)).^(-1/(disC+1));
        beta = beta.*(-1).^randi([0,1],N/2,D);
        beta(repmat(rand(N/2,1)>proC,1,D)) = 1;
        Offspring = [(parent1Dec+parent2Dec)/2+beta.*(parent1Dec-parent2Dec)/2
                     (parent1Dec+parent2Dec)/2-beta.*(parent1Dec-parent2Dec)/2];
    else
        % DE
        [CR,F]     = deal(1,0.5);
        parent1Dec = ParentDec(1:N/3,:);
        parent2Dec = ParentDec(N/3+1:N/3*2,:);
        parent3Dec = ParentDec(N/3*2+1:end,:);
        Offspring  = parent1Dec;
        Site       = rand(N/3,D) < CR;
        Offspring(Site) = Offspring(Site) + F*(parent2Dec(Site)-parent3Dec(Site));
    end
    % PolynomialM
    [proM,disM] = deal(0.5,20);
    [N,D]       = size(Offspring);
    Site  = rand(N,D) < proM/length(DecVariables);
    miu   = rand(N,D);
    temp  = Site & miu<=0.5;
    Lower = repmat(Boundary(2,DecVariables),N,1);
    Upper = repmat(Boundary(1,DecVariables),N,1);
    Offspring(temp) = Offspring(temp)+(Upper(temp)-Lower(temp)).*((2.*miu(temp)+(1-2.*miu(temp)).*...
                   (1-(Offspring(temp)-Lower(temp))./(Upper(temp)-Lower(temp))).^(disM+1)).^(1/(disM+1))-1);
    temp = Site & miu>0.5; 
    Offspring(temp) = Offspring(temp)+(Upper(temp)-Lower(temp)).*(1-(2.*(1-miu(temp))+2.*(miu(temp)-0.5).*...
                   (1-(Upper(temp)-Offspring(temp))./(Upper(temp)-Lower(temp))).^(disM+1)).^(1/(disM+1)));
    
    %% Generate the final offsprings
    Population(:,DecVariables) = Offspring(1:size(Population,1),:);
    Offspring = Population;
    Lower     = repmat(Boundary(2,:),size(Offspring,1),1);
    Upper     = repmat(Boundary(1,:),size(Offspring,1),1);
    Offspring = max(min(Offspring,Upper),Lower);
end